@@ -15,8 +15,20 @@
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from .dataset import Dataset
-from .eccodes import EcCodesError
-from .messages import Stream
+# cfgrib core API depends on the ECMWF ecCodes C-library only
 
-__all__ = ['Dataset', 'EcCodesError', 'Stream']
+from .cfmessage import CfMessage
+from .dataset import Dataset, DatasetBuildError, open_file
+from .messages import Message, FileStream
+
+__all__ = ['CfMessage', 'Dataset', 'DatasetBuildError', 'FileStream', 'Message', 'open_file']
+
+# NOTE: xarray is not a hard dependency, but let's provide helpers if it is available.
+
+try:
+    from .xarray_store import open_dataset
+    from .xarray_to_grib import canonical_dataset_to_grib, to_grib
+
+    __all__ += ['canonical_dataset_to_grib', 'open_dataset', 'to_grib']
+except ImportError:
+    pass
