@@ -192,6 +192,15 @@ int codes_write_message(codes_handle* h,const char* file,const char* mode);
  */
 codes_handle* codes_grib_handle_new_from_samples (codes_context* c, const char* sample_name);
 
+/**
+*  Clone an existing handle using the context of the original handle,
+*  The message is copied and reparsed
+*
+* @param h           : The handle to be cloned
+* @return            the new handle, NULL if the message is invalid or a problem is encountered
+*/
+codes_handle* codes_handle_clone(codes_handle* h)                 ;
+
 /**
 *  Frees a handle, also frees the message if it is not a user message
 *  @see  codes_handle_new_from_message
@@ -363,6 +372,18 @@ int codes_set_bytes(codes_handle* h, const char*  key, const unsigned char* byte
 */
 int codes_set_double_array(codes_handle* h, const char* key, const double* vals, size_t length);
 
+/**
+*  Set a long array from a key. If several keys of the same name are present, the last one is set
+*  @see  codes_get_long_array
+*
+* @param h           : the handle to set the data to
+* @param key         : the key to be searched
+* @param vals        : the address of a long array where the data will be read
+* @param length      : a size_t that contains the length of the long array on input
+* @return            0 if OK, integer value on error
+*/
+int codes_set_long_array(codes_handle* h, const char* key, const long* vals, size_t length);
+
 /**
 *  Get the API version
 *
