@@ -166,6 +166,14 @@ def codes_handle_new_from_file(fileobj, product_kind=CODES_PRODUCT_GRIB):
         raise
 
 
+def codes_handle_clone(handle):
+    # type: (cffi.FFI.CData) -> cffi.FFI.CData
+    cloned_handle = lib.codes_handle_clone(handle)
+    if cloned_handle is ffi.NULL:
+        raise EcCodesError(lib.GRIB_NULL_POINTER)
+    return cloned_handle
+
+
 codes_index_delete = lib.codes_index_delete
 codes_handle_delete = lib.codes_handle_delete
 
@@ -624,13 +632,23 @@ def codes_set_double_array(handle, key, values):
     codes_set_double_array(handle, key, c_values, size)
 
 
+def codes_set_long_array(handle, key, values):
+    # type: (cffi.FFI.CData, bytes, T.List[int]) -> None
+    size = len(values)
+    c_values = ffi.new("long []", values)
+    codes_set_long_array = check_return(lib.codes_set_long_array)
+    codes_set_long_array(handle, key, c_values, size)
+
+
 def codes_set_array(handle, key, values):
     # type: (cffi.FFI.CData, bytes, T.List[T.Any]) -> None
     if len(values) > 0:
         if isinstance(values[0], float):
             codes_set_double_array(handle, key, values)
+        elif isinstance(values[0], int):
+            codes_set_long_array(handle, key, values)
         else:
-            raise NotImplementedError("Unsupported value type: %r" % type(values[0]))
+            raise TypeError("Unsupported value type: %r" % type(values[0]))
     else:
         raise ValueError("Cannot set an empty list.")
 
